import { Delegate, MatchCallback, Route } from "./route-recognizer/dsl";
import { encodePathSegment, normalizePath, normalizeSegment } from "./route-recognizer/normalizer";
export { Delegate, MatchCallback } from "./route-recognizer/dsl";
export interface Params {
    [key: string]: unknown;
    [key: number]: unknown;
    queryParams?: {
        [key: string]: unknown;
        [key: number]: unknown;
    } | null;
}
interface Handler<THandler> {
    handler: THandler;
    names: string[];
    shouldDecodes: boolean[];
}
export interface QueryParams {
    [param: string]: string[] | string | null | undefined;
}
export interface Result<THandler> {
    handler: THandler;
    params: Params;
    isDynamic: boolean;
}
export interface Results<THandler> extends ArrayLike<Result<THandler>> {
    queryParams: QueryParams;
    slice(start?: number, end?: number): Result<THandler>[];
    splice(start: number, deleteCount: number, ...items: Result<THandler>[]): Result<THandler>[];
    push(...results: Result<THandler>[]): number;
}
declare class RouteRecognizer<THandler = string> {
    private rootState;
    private names;
    map: (context: MatchCallback<THandler>, addCallback?: (router: this, routes: Route<THandler>[]) => void) => void;
    delegate: Delegate<THandler> | undefined;
    constructor();
    static VERSION: string;
    static ENCODE_AND_DECODE_PATH_SEGMENTS: boolean;
    static Normalizer: {
        normalizeSegment: typeof normalizeSegment;
        normalizePath: typeof normalizePath;
        encodePathSegment: typeof encodePathSegment;
    };
    add(routes: Route<THandler>[], options?: {
        as: string;
    }): void;
    handlersFor(name: string): Handler<THandler>[];
    hasRoute(name: string): boolean;
    generate(name: string, params?: Params | null): string;
    generateQueryString(params: Params): string;
    parseQueryString(queryString: string): QueryParams;
    recognize(path: string): Results<THandler> | undefined;
}
export default RouteRecognizer;
